Struct libimagentryedit::error::EditError []

pub struct EditError(pub EditErrorKind, _);

The Error type.

This tuple struct is made of two elements:

  • an ErrorKind which is used to determine the type of the error.
  • An internal State, not meant for direct use outside of error_chain internals, containing:
    • a backtrace, generated when the error is created.
    • an error chain, used for the implementation of Error::cause().

Methods

impl EditError

Constructs an error from a kind, and generates a backtrace.

Constructs a chained error from another error and a kind, and generates a backtrace.

Returns the kind of the error.

Iterates over the error chain.

Returns the backtrace associated with this error.

Methods from Deref<Target = EditErrorKind>

A string describing the error kind.