Trait libimagentryedit::error::ResultExt
[−]
pub trait ResultExt<T> {
fn chain_err<F, EK>(self, callback: F) -> Result<T, EditError>
where
F: FnOnce() -> EK,
EK: Into<EditErrorKind>;
}Additional methods for Result, for easy interaction with this crate.
Required Methods
fn chain_err<F, EK>(self, callback: F) -> Result<T, EditError> where
F: FnOnce() -> EK,
EK: Into<EditErrorKind>,
F: FnOnce() -> EK,
EK: Into<EditErrorKind>,
If the Result is an Err then chain_err evaluates the closure,
which returns some type that can be converted to ErrorKind, boxes
the original error to store as the cause, then returns a new error
containing the original error.
Implementations on Foreign Types
impl<T, E> ResultExt<T> for Result<T, E> where
E: Error + Send + 'static,
E: Error + Send + 'static,