Struct libimagentryedit::error::EditError
[−]
pub struct EditError(pub EditErrorKind, _);
The Error type.
This tuple struct is made of two elements:
- an
ErrorKindwhich is used to determine the type of the error. - An internal
State, not meant for direct use outside oferror_chaininternals, containing:- a backtrace, generated when the error is created.
- an error chain, used for the implementation of
Error::cause().
Methods
impl EditError
fn from_kind(kind: EditErrorKind) -> EditError
Constructs an error from a kind, and generates a backtrace.
fn with_chain<E, K>(error: E, kind: K) -> EditError where
E: Error + Send + 'static,
K: Into<EditErrorKind>,
E: Error + Send + 'static,
K: Into<EditErrorKind>,
Constructs a chained error from another error and a kind, and generates a backtrace.
fn kind(&self) -> &EditErrorKind
Returns the kind of the error.
fn iter(&self) -> ErrorChainIter
Iterates over the error chain.
fn backtrace(&self) -> Option<&Backtrace>
Returns the backtrace associated with this error.
Methods from Deref<Target = EditErrorKind>
fn description(&self) -> &str
A string describing the error kind.